library(readxl)
library(tidyverse)
library(dunn.test)


#set working directory
getwd()
setwd("")

#attach data
brookhaven_census_data <- read_excel("Brookhaven_ACS2017_data.xlsx")
brookhaven_census_data

names(brookhaven_census_data)

#add new variable:Children school age percentage
brookhaven_census_data$Children_School_Age_Pct <- brookhaven_census_data$Age_Under_18_Pct - brookhaven_census_data$Age_Under_5_Pct
brookhaven_census_data

#reorder Districts: North, Middle, South
brookhaven_census_data$Districts <- factor(brookhaven_census_data$Districts, levels=c("North", "Middle", "South"))

#Visualization
#boxplot
#400 x 250
#word: width 3.5

#household size
brookhaven_census_data %>%
  ggplot(aes(x=Districts, y=Mean_HH_Size)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(width = 0.2, alpha = 0.7, shape="x", size=3) +
  labs(y="Mean", title="Household Size") +
  theme_classic() +
  theme(plot.title = element_text(hjust = 0.5)) 

#highschool graduate
brookhaven_census_data %>%
  ggplot(aes(x=Districts, y=Highschool_Grad_Pct)) + 
  geom_boxplot() +
  geom_jitter(width = 0.2, alpha = 0.7, shape="x", size=3) +
  labs(title="High School Graduate", y="Percent")+
  theme_classic() +
  theme(plot.title = element_text(hjust = 0.5)) 

#bachelor's and higher graduate
brookhaven_census_data %>%
  ggplot(aes(x=Districts, y=Bachelor_Grad_Up_Pct)) + 
  geom_boxplot() +
  geom_jitter(width = 0.2, alpha = 0.7, color = "black", shape="x", size=3) +
  labs(title="Bachelor's Degree or Higher", y="Percent") +
  theme_classic() +
  theme(plot.title = element_text(hjust = 0.5)) 

#Spanish spoken at home
brookhaven_census_data %>%
  ggplot(aes(x=Districts, y=Spanish_Lang_Home_Pct)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(width = 0.2, alpha = 0.7, color = "black", shape="x", size=3) +
  labs(title="Spanish Spoken at Home", y="Percent") +
  theme_classic() +
  theme(plot.title = element_text(hjust = 0.5)) 

#Median income
brookhaven_census_data %>%
  ggplot(aes(x=Districts, y=Median_HH_Income_USD)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(width = 0.2, alpha = 0.7, color = "black", shape="x", size=3) +
  labs(title="Household Income (Median)", y="USD") +
  theme_classic() +
  theme(plot.title = element_text(hjust = 0.5)) +
  scale_y_continuous(labels = scales::comma)

#house value
brookhaven_census_data %>%
  ggplot(aes(x=Districts, y=Median_House_Value_USD)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(width = 0.2, alpha = 0.7, color = "black", shape="x", size=3) +
  labs(title="House Value (Median)", y="USD") +
  theme_classic() +
  theme(plot.title = element_text(hjust = 0.5)) +
  scale_y_continuous(labels = scales::comma)

#Median age
brookhaven_census_data %>%
  ggplot(aes(x=Districts, y=Median_Age_Years)) + 
  geom_boxplot(outlier.shape=NA) +
  geom_jitter(width = 0.2, alpha = 0.7, color = "black", shape="x", size=3) +
  labs(title="Age (Median)", y="Years") +
  theme_classic() +
  theme(plot.title = element_text(hjust = 0.5)) 

#Age 65 and over
brookhaven_census_data %>%
  ggplot(aes(x=Districts, y=Age_65_Over_Pct)) + 
  geom_boxplot(outlier.shape=NA) +
  geom_jitter(width = 0.2, alpha = 0.7, color = "black", shape="x", size=3) +
  labs(title="Age 65 and Over", y="Percent") +
  theme_classic() +
  theme(plot.title = element_text(hjust = 0.5)) 

#race white
brookhaven_census_data %>%
  ggplot(aes(x=Districts, y=Race_White_Pct)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(width = 0.2, alpha = 0.7, color = "black", shape="x", size=3) +
  labs(title="Race: White", y="Percent") +
  theme_classic() +
  theme(plot.title = element_text(hjust = 0.5)) 

#hispanic or latino
brookhaven_census_data %>%
  ggplot(aes(x=Districts, y=HispLatino_Pct)) + 
  geom_boxplot(outlier.shape = NA) +
  geom_jitter(width = 0.2, alpha = 0.7, color = "black", shape="x", size=3) +
  labs(title="Hispanic or Latino\n(of any race)", y="Percent") +
  theme_classic() +
  theme(plot.title = element_text(hjust = 0.5)) 

#White not hispanic or latino
brookhaven_census_data %>%
  ggplot(aes(x=Districts, y=White_NoHispanicLatino_Pct)) + 
  geom_boxplot(outlier.shape=NA) +
  geom_jitter(width = 0.2, alpha = 0.7, color = "black", shape="x", size=3) +
  labs(title="White\n(not Hispanic or Latino)", y="Percent") +
  theme_classic() +
  theme(plot.title = element_text(hjust = 0.5)) 

#age 5-18
brookhaven_census_data %>%
  ggplot(aes(x=Districts, y=Children_School_Age_Pct)) + 
  geom_boxplot(outlier.shape=NA) +
  geom_jitter(width = 0.2, alpha = 0.7, color = "black", shape="x", size=3) +
  labs(title="Age 5-18", y="Percent") +
  theme_classic() +
  theme(plot.title = element_text(hjust = 0.5)) 

#

#Anova
anova_HH_size <- aov(Mean_HH_Size ~ Districts, data=brookhaven_census_data)
summary(anova_HH_size)

anova_Highschool_Grad_Pct <- aov(Highschool_Grad_Pct ~ Districts, data=brookhaven_census_data)
summary(anova_Highschool_Grad_Pct)
TukeyHSD(anova_Highschool_Grad_Pct) #match

anova_Bachelor_Grad_Up_Pct <- aov(Bachelor_Grad_Up_Pct ~ Districts, data=brookhaven_census_data)
summary(anova_Bachelor_Grad_Up_Pct)
TukeyHSD(anova_Bachelor_Grad_Up_Pct)

anova_Spanish_Lang_Home_Pct  <- aov(Spanish_Lang_Home_Pct ~ Districts, data=brookhaven_census_data)
summary(anova_Spanish_Lang_Home_Pct)
TukeyHSD(anova_Spanish_Lang_Home_Pct)

anova_Median_HH_Income_USD  <- aov(Median_HH_Income_USD ~ Districts, data=brookhaven_census_data)
summary(anova_Median_HH_Income_USD)
TukeyHSD(anova_Median_HH_Income_USD) #match

anova_Median_House_Value_USD  <- aov(Median_House_Value_USD ~ Districts, data=brookhaven_census_data)
summary(anova_Median_House_Value_USD)
TukeyHSD(anova_Median_House_Value_USD) #match

anova_Median_Age_Years  <- aov(Median_Age_Years ~ Districts, data=brookhaven_census_data)
summary(anova_Median_Age_Years)

anova_Age_65_Over_Pct  <- aov(Age_65_Over_Pct ~ Districts, data=brookhaven_census_data)
summary(anova_Age_65_Over_Pct)

anova_Race_White_Pct  <- aov(Race_White_Pct ~ Districts, data=brookhaven_census_data)
summary(anova_Race_White_Pct)

anova_HispLatino_Pct  <- aov(HispLatino_Pct ~ Districts, data=brookhaven_census_data) 
summary(anova_HispLatino_Pct)
TukeyHSD(anova_HispLatino_Pct)

anova_White_NoHispanicLatino_Pct  <- aov(White_NoHispanicLatino_Pct ~ Districts, data=brookhaven_census_data)
summary(anova_White_NoHispanicLatino_Pct)

anova_Children_School_Age_Pct  <- aov(Children_School_Age_Pct ~ Districts, data=brookhaven_census_data)
summary(anova_Children_School_Age_Pct )

#Kruskal-Wallis & Dunn Test
#match
dunn.test(brookhaven_census_data$Highschool_Grad_Pct, g=brookhaven_census_data$Districts, method="bonferroni") #match
dunn.test(brookhaven_census_data$Median_HH_Income_USD, g=brookhaven_census_data$Districts, method="bonferroni") #match
dunn.test(brookhaven_census_data$Median_House_Value_USD, g=brookhaven_census_data$Districts, method="bonferroni") #match
dunn.test(brookhaven_census_data$HispLatino_Pct, g=brookhaven_census_data$Districts, method="bonferroni") #match
dunn.test(brookhaven_census_data$White_NoHispanicLatino_Pct, g=brookhaven_census_data$Districts, method="bonferroni") #match

#significant but not match
dunn.test(brookhaven_census_data$Bachelor_Grad_Up_Pct, g=brookhaven_census_data$Districts, method="bonferroni")
dunn.test(brookhaven_census_data$Spanish_Lang_Home_Pct, g=brookhaven_census_data$Districts, method="bonferroni")

#not significant
dunn.test(brookhaven_census_data$Mean_HH_Size, g=brookhaven_census_data$Districts, method="bonferroni")
dunn.test(brookhaven_census_data$Median_Age_Years, g=brookhaven_census_data$Districts, method="bonferroni")
dunn.test(brookhaven_census_data$Age_65_Over_Pct, g=brookhaven_census_data$Districts, method="bonferroni")
dunn.test(brookhaven_census_data$Race_White_Pct, g=brookhaven_census_data$Districts, method="bonferroni")
dunn.test(brookhaven_census_data$Children_School_Age_Pct, g=brookhaven_census_data$Districts, method="bonferroni")

